Package: goodpractice
Title: Advice on R Package Building
Version: 1.2.0
Authors@R: 
    c(
      person(given = "Mark",
             family = "Padgham",
             role = c("aut", "cre"),
             email = "mark@ropensci.org",
             comment = c(ORCID = "0000-0003-2172-5265")),
      person(given = "Ascent Digital Services UK Limited",
             role = "cph",
             comment = c(GitHub = "MangoTheCat")),
      person(given = "Karina",
             family = "Marks",
             role = "aut",
             email = "karina.marks@ascent.io",
             comment = c(GitHub = "KarinaMarks")),       
      person(given = "Daniel",
             family = "de Bortoli",
             role = c("aut"),
             comment = c(GitHub = "ddbortoli")),
      person(given = "Gabor",
             family = "Csardi",
             role = "aut",
             email = "csardi.gabor@gmail.com"),
      person(given = "Hannah",
             family = "Frick",
             role = "aut",
             email = "hannah.frick@gmail.com"),
      person(given = "Owen",
             family = "Jones",
             role = "aut",
             email = "owenjonesuob@gmail.com",
             comment = c(GitHub = "owenjonesuob")),
      person(given = "Hannah",
             family = "Alexander",
             role = "aut",
             email = "halexander@mango-solutions.com"),
      person(given = "Ana",
             family = "Simmons",
             role = c("ctb"),
             email = "ana.simmons@ascent.io",
             comment = c(GitHub = "anasimmons")),
      person(given = "Fabian",
             family = "Scheipl",
             role = "ctb",
             comment = c(GitHub = "fabian-s")),
      person(given = "Athanasia Mo",
             family = "Mowinckel",
             email = "a.m.mowinckel@psykologi.uio.no",
             role = c("aut"),
            comment = c(
                GitHub = "drmowinckels", 
                ORCID = "0000-0002-5756-0223")
       ))
Description: Give advice about good practices when building R packages.
    Advice includes functions and syntax to avoid, package structure, code
    complexity, code formatting, etc.
License: MIT + file LICENSE
URL: https://docs.ropensci.org/goodpractice/,
        https://github.com/ropensci-review-tools/goodpractice
BugReports: https://github.com/ropensci-review-tools/goodpractice/issues
Depends: R (>= 4.3.0)
Imports: cli, covr, curl, cyclocomp (>= 1.1.0), desc, jsonlite, lintr
        (>= 3.0.0), praise, rcmdcheck, roxygen2, rstudioapi, spelling,
        tools, treesitter, treesitter.r, urlchecker, utils, whoami,
        withr
Suggests: future, future.apply, kableExtra, knitr, rmarkdown, testthat
        (>= 3.0.0)
VignetteBuilder: knitr
Encoding: UTF-8
Config/testthat/edition: 3
Config/ropensci/maintainer: staff
Collate: 'api.R' 'customization.R' 'lists.R' 'chk_avoided_packages.R'
        'treesitter.R' 'chk_code_structure.R' 'chk_covr.R'
        'chk_cyclocomp.R' 'chk_description.R' 'chk_generic.R'
        'chk_lintr.R' 'chk_namespace.R' 'chk_rcmdcheck.R' 'chk_rd.R'
        'chk_revdep.R' 'chk_roxygen2.R' 'chk_spelling.R'
        'chk_tidyverse.R' 'chk_urlchecker.R' 'chk_vignette.R' 'gp.R'
        'package.R' 'prep_utils.R' 'prep_covr.R' 'prep_cyclocomp.R'
        'prep_description.R' 'prep_lintr.R' 'prep_namespace.R'
        'prep_rcmdcheck.R' 'prep_rd.R' 'prep_revdep.R'
        'prep_roxygen2.R' 'prep_source.R' 'prep_spelling.R'
        'prep_tidyverse.R' 'prep_urlchecker.R' 'prep_vignette.R'
        'print.R' 'rstudio_markers.R' 'utils.R'
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-31 11:01:10 UTC; smexus
Author: Mark Padgham [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2172-5265>),
  Ascent Digital Services UK Limited [cph] (GitHub: MangoTheCat),
  Karina Marks [aut] (GitHub: KarinaMarks),
  Daniel de Bortoli [aut] (GitHub: ddbortoli),
  Gabor Csardi [aut],
  Hannah Frick [aut],
  Owen Jones [aut] (GitHub: owenjonesuob),
  Hannah Alexander [aut],
  Ana Simmons [ctb] (GitHub: anasimmons),
  Fabian Scheipl [ctb] (GitHub: fabian-s),
  Athanasia Mo Mowinckel [aut] (GitHub: drmowinckels, ORCID:
    <https://orcid.org/0000-0002-5756-0223>)
Maintainer: Mark Padgham <mark@ropensci.org>
Repository: CRAN
Date/Publication: 2026-08-31 18:40:08 UTC
