Package: goodpackage
Title: Advice on R package building
Version: 1.0.0
Author: Gabor Csardi
Maintainer: Gabor Csardi <gcsardi@mango-solutions.com>
Description: Give advice about good practices when building R packages.
License: GPL-2
URL: https://github.com/mangothecat/goodpractice
BugReports: https://github.com/mangothecat/goodpractice/issues
RoxygenNote: 5.0.1
