# Generated by roxygen2: do not edit by hand

S3method(print,goodPractice)
export(all_check_groups)
export(all_checks)
export(checks)
export(checks_by_group)
export(default_checks)
export(describe_check)
export(describe_check_groups)
export(export_json)
export(failed_checks)
export(failed_positions)
export(goodpractice)
export(gp)
export(learn_skill_gp)
export(make_check)
export(make_prep)
export(results)
export(tidyverse_checks)
export(use_skill_gp)
importFrom(covr,
  package_coverage,
  percent_coverage,
  zero_coverage
)
importFrom(cyclocomp,cyclocomp_package_dir)
importFrom(desc,
  desc_get,
  desc_get_collate,
  description
)
importFrom(jsonlite,toJSON)
importFrom(lintr,lint_package)
importFrom(praise,praise)
importFrom(rcmdcheck,rcmdcheck)
importFrom(roxygen2,parse_package)
importFrom(rstudioapi,
  callFun,
  hasFun
)
importFrom(spelling,spell_check_package)
importFrom(stats,setNames)
importFrom(urlchecker,url_check)
importFrom(utils,
  getParseData,
  head
)
importFrom(whoami,
  fullname,
  username
)
importFrom(withr,with_options)
