no_value <- function(x) x + 1
no_examples <- function(x) x + 2
dontrun_example <- function(x) x + 3
all_wrapped <- function(x) x + 4
good_func <- function(x) x + 5
print.badrd <- function(x, ...) cat("badrd\n")
internal_func <- function(x) x + 6
