myFunc <- function(x ,y)
{
    if(x == NA & y > 0)return( x )
    z <- x+y
    # z <- z * 2
    w <- f (z)
    msg <- 'hello world'   
    x %>% sum() |> print()
    a_very_long_and_excessively_named_function_variable_name_that_goes_well_beyond_the_one_hundred_twenty_char_limit_for_line_length <- w
    result = T
    idx <- 1:length(z); w <- z
	return(z)
}


