#' goodpractice: Advice on R Package Building
#'
#' Give advice about good practices when building R packages. Advice includes
#' functions and syntax to avoid, package structure, code complexity, code
#' formatting, etc.
#' @family main
#' @name goodpractice-package
#' @aliases goodpractice-package
"_PACKAGE"
