## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----windowns-flag, echo = FALSE----------------------------------------------
# The bash commands are likely to fail on winddows:
on_windows <- identical(.Platform$OS.type, "windows")

## ----echo = FALSE, eval = TRUE, output = TRUE---------------------------------
cli::cli_alert_success("No problems found")

