% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lists.R
\name{checks_by_group}
\alias{checks_by_group}
\title{Select checks by check group}
\usage{
checks_by_group(...)
}
\arguments{
\item{...}{Group names as character strings. Use \code{\link[=all_check_groups]{all_check_groups()}} to
see available names.}
}
\value{
Character vector of check names
}
\description{
Returns the names of all checks that belong to the given group(s).
This makes it easy to run or inspect a specific category of checks
without knowing individual check names.
}
\examples{
# run only DESCRIPTION and namespace checks
checks_by_group("description", "namespace")

# see what the lintr group covers
checks_by_group("lintr")
# See all checks by group:
lapply(all_check_groups(), checks_by_group)
# use directly in gp()
\dontrun{
  gp(".", checks = checks_by_group("description", "lintr"))
}
}
\seealso{
Other check_groups:
\code{\link[=all_check_groups]{all_check_groups()}},
\code{\link[=all_checks]{all_checks()}},
\code{\link[=default_checks]{default_checks()}},
\code{\link[=describe_check]{describe_check()}},
\code{\link[=describe_check_groups]{describe_check_groups()}},
\code{\link[=tidyverse_checks]{tidyverse_checks()}}
}
\concept{check_groups}
