% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lists.R
\name{tidyverse_checks}
\alias{tidyverse_checks}
\title{List the names of tidyverse style checks}
\usage{
tidyverse_checks()
}
\value{
Character vector of tidyverse check names
}
\description{
These checks are optional and not included in the default set.
They are powered by \code{\link[lintr]{lint_package}} using lintr's
default linter set and respect any \code{.lintr} configuration file
in the package root (e.g. to disable specific linters or add exclusions).
Add them via \code{checks = c(default_checks(), tidyverse_checks())}.
}
\examples{
tidyverse_checks()
}
\seealso{
Other check_groups:
\code{\link[=all_check_groups]{all_check_groups()}},
\code{\link[=all_checks]{all_checks()}},
\code{\link[=checks_by_group]{checks_by_group()}},
\code{\link[=default_checks]{default_checks()}},
\code{\link[=describe_check]{describe_check()}},
\code{\link[=describe_check_groups]{describe_check_groups()}}
}
\concept{check_groups}
