% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/package.R
\name{func1}
\alias{func1}
\title{Random function}
\usage{
func1()
}
\description{
Random function
}
\value{
Nothing useful.
}
\examples{
func1()
}
