\name{my_func}
\alias{my_func}
\title{Calcualte the incremnet of a value}
\description{
This functon compuets the incremnet of the givn value.
}
\usage{
my_func(x)
}
\arguments{
\item{x}{A numbr to incremnet.}
}
