\name{good_func}
\alias{good_func}
\title{Properly documented function}
\usage{
good_func(x)
}
\description{
Has everything: value, examples, runnable code.
}
\value{
A number.
}
\examples{
good_func(1)
}
